@@ -1,6 +1,6 @@
 $(document).ready(() => {
     $(".menagerie-copy-button").click((e) => {
-        const text = $(e.target).parent().siblings("code").text();
+        const text = $(e.currentTarget).siblings("code").text();
         navigator.clipboard.writeText(text);
     });
 });
\ No newline at end of file
